@@ -23,7 +23,9 @@ def _build(path, pwd=None):
         _build(path, here)
 
 
-def generate_view(directory, name):
+def generate_view(directory, name=None):
+    if not name:
+        name = raw_input('View Name: ')
     view = os.path.join("app", "views", name + ".html")
     split = name.split(os.sep)
     namespace = split[-1]
@@ -42,7 +44,7 @@ def generate_view(directory, name):
 
     #import styles styles
     with open(os.path.join(directory, 'lib', 'styles', 'styles.scss'), 'a') as styles:
-        styles.write('@import "site/%s";\n' % name)
+        styles.write('\n@import "site/%s";' % name)
 
 
 if __name__ == "__main__":
