@@ -13,7 +13,10 @@ class Command(BaseCommand):
         else:
             dir = '.'
         if not args:
-            raise CommandError('Need a service name as an argument')
-        for service_name in args:
+            service_name = raw_input('Name of Service:' )
             generate_service(dir, service_name)
             self.stdout.write('Successfully initialized service "%s"' % service_name)
+        else:
+            for service_name in args:
+                generate_service(dir, service_name)
+                self.stdout.write('Successfully initialized service "%s"' % service_name)
