@@ -13,7 +13,10 @@ class Command(BaseCommand):
         else:
             dir = '.'
         if not args:
-            raise CommandError('Need View Name as an argument')
-        for view_name in args:
+            view_name = raw_input("View Name: ")
             generate_view(os.path.join(dir, 'assets'), view_name)
             self.stdout.write('Successfully initialized view "%s"' % view_name)
+        else:
+            for view_name in args:
+                generate_view(os.path.join(dir, 'assets'), view_name)
+                self.stdout.write('Successfully initialized view "%s"' % view_name)
